class puppet_enterprise::master::puppetserver(
  $metrics_enabled,
  $metrics_server_id,
  $metrics_jmx_enabled,
  $metrics_graphite_enabled,
  $metrics_graphite_host,
  $metrics_graphite_port,
  $metrics_graphite_update_interval_seconds,
  $profiler_enabled,
  $jruby_max_active_instances                = undef,
  $certname                                  = $::clientcert,
  $localcacert                               = $puppet_enterprise::params::localcacert,
  $puppet_admin_certs                        = [],
  $static_files                              = {},
  $java_args                                 = $puppet_enterprise::params::puppetserver_java_args,
  $tk_jetty_max_threads                      = 100,
) inherits puppet_enterprise::params {

  pe_validate_array($puppet_admin_certs)

  $classifier_client_certname = $puppet_enterprise::params::classifier_client_certname
  $container = 'puppetserver'
  $_puppet_admin_certs = pe_union([$classifier_client_certname], $puppet_admin_certs)

  File {
    ensure => present,
    owner  => 'pe-puppet',
    group  => 'pe-puppet',
    mode   => '0640',
  }

  Pe_concat {
    owner  => 'pe-puppet',
    group  => 'pe-puppet',
    mode   => '0640',
  }

  Puppet_enterprise::Trapperkeeper::Bootstrap_cfg {
    container => $container,
  }

  $confdir = "/etc/puppetlabs/${container}"

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:master jetty9-service" :
    namespace => 'puppetlabs.trapperkeeper.services.webserver.jetty9-service',
    service   => 'jetty9-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'pe-master-service' :
    namespace => 'puppetlabs.enterprise.services.master.master-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'request-handler-service' :
    namespace => 'puppetlabs.services.request-handler.request-handler-service',
  }
  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'jruby-puppet-pooled-service' :
    namespace => 'puppetlabs.services.jruby.jruby-puppet-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'metrics-puppet-profiler-service' :
    namespace => 'puppetlabs.enterprise.services.puppet-profiler.puppet-profiler-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'metrics-service' :
    namespace => 'puppetlabs.enterprise.services.metrics.metrics-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'puppet-server-config-service' :
    namespace => 'puppetlabs.services.config.puppet-server-config-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'puppet-admin-service' :
    namespace => 'puppetlabs.services.puppet-admin.puppet-admin-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'webrouting-service' :
    namespace => 'puppetlabs.trapperkeeper.services.webrouting.webrouting-service',
  }

  # Uses
  #   $certname
  #   $localcacert
  #   $tk_jetty_max_threads
  file { "${confdir}/conf.d/webserver.conf" :
    content => template('puppet_enterprise/master/puppetserver/webserver.conf.erb'),
    notify => Service["pe-${container}"],
  }

  file { "${confdir}/conf.d/web-routes.conf" :
    content => template('puppet_enterprise/master/puppetserver/web-routes.conf.erb'),
    notify  => Service["pe-${container}"],
  }

  # Uses
  #   $profiler_enabled
  #   $_puppet_admin_certs
  file { "${confdir}/conf.d/pe-puppet-server.conf" :
    content => template('puppet_enterprise/master/puppetserver/puppet-server.conf.erb'),
    notify => Service["pe-${container}"],
  }

  # Uses
  #   $confdir
  #   $certname
  file { "${confdir}/conf.d/global.conf" :
    content => template('puppet_enterprise/master/puppetserver/global.conf.erb'),
    notify => Service["pe-${container}"],
  }


  # Uses
  #   $metrics_enabled
  #   $metrics_server_id
  #   $metrics_jmx_enabled
  #   $metrics_graphite_enabled
  #   $metrics_graphite_host
  #   $metrics_graphite_port
  #   $metrics_graphite_update_interval_seconds
  file { "${confdir}/conf.d/metrics.conf" :
    content => template('puppet_enterprise/master/puppetserver/metrics.conf.erb'),
    notify => Service["pe-${container}"],
  }

  if !pe_empty($java_args) {
    $puppetserver_initconf = "${puppet_enterprise::params::defaults_dir}/pe-puppetserver"
    create_resources(
      'pe_ini_subsetting',
      create_java_args_subsettings_hash(
        'pe-puppetserver',
        $java_args,
        { path => $puppetserver_initconf,
          require => Package['pe-puppetserver'],
          notify => Service["pe-${container}"],
        })
    )
  }

  service { "pe-${container}":
    ensure    => running,
    enable    => true,
  }
}
